@@ -159,7 +159,10 @@ function _gnocchi_install_grafana {
         sudo yum install "$GRAFANA_RPM_PKG"
     fi
 
-    git_clone ${GRAFANA_PLUGINS_REPO} ${GRAFANA_PLUGINS_DIR}
+    # NOTE(sileht): We current support only 2.6, when 
+    # plugin for 3.0 will be ready we will switch to the grafana
+    # plugin tool to install it
+    git_clone ${GRAFANA_PLUGINS_REPO} ${GRAFANA_PLUGINS_DIR} 2.6
     # Grafana-server does not handle symlink :(
     sudo mkdir -p /usr/share/grafana/public/app/plugins/datasource/gnocchi
     sudo mount -o bind ${GRAFANA_PLUGINS_DIR}/datasources/gnocchi /usr/share/grafana/public/app/plugins/datasource/gnocchi
@@ -354,9 +357,10 @@ function init_gnocchi {
 }
 
 function preinstall_gnocchi {
-    # Needed to build psycopg2
     if is_ubuntu; then
-        install_package libpq-dev
+        # libpq-dev is needed to build psycopg2
+        # uuid-runtime is needed to use the uuidgen command
+        install_package libpq-dev uuid-runtime
     else
         install_package postgresql-devel
     fi
